require 'spec_helper'

describe Rack::Monitor::OpenTSDB do

  before :each do
    @app = double(:app)
    @env = {'REQUEST_METHOD' => 'GET', 'PATH_INFO' => '/path'}
    @sut = Rack::Monitor::OpenTSDB.new(@app, 'test.monitor')
  end

  it 'starts with empty stats' do
    expect(@sut.instance_variable_get('@stats')).to be_empty
  end

  describe :call do

    it 'does return apps result' do
      allow(@app).to receive(:call).and_return(['status', 'headers', 'body'])
      expect(@sut.call @env).to eq(['status', 'headers', 'body'])
    end

    describe 'stats' do
      before do
        allow(@app).to receive(:call).and_return(['200', 'headers', 'body'])
        @sut.call @env
        @stats = @sut.instance_variable_get('@stats')
      end

      it 'includes path' do
        expect(@stats).to include 'GET /path'
      end

      it 'includes status' do
        expect(@stats['GET /path']).to include '200'
      end

    end

  end

  describe 'call with regexable path' do

      before do
        allow(@app).to receive(:call).and_return(['200', 'headers', 'body'])
        @sut.call({'REQUEST_METHOD' => 'GET', 'PATH_INFO' => '/some/longer/path'})
        @stats = @sut.instance_variable_get('@stats')
      end

      it 'includes path' do
        # Default regex does shorten to first path-segment
        expect(@stats).to include 'GET /some'
      end
  end

end
